summaryrefslogtreecommitdiffstats
path: root/libktorrent/kademlia/key.h
diff options
context:
space:
mode:
Diffstat (limited to 'libktorrent/kademlia/key.h')
-rw-r--r--libktorrent/kademlia/key.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libktorrent/kademlia/key.h b/libktorrent/kademlia/key.h
index e818dc1..e383a5e 100644
--- a/libktorrent/kademlia/key.h
+++ b/libktorrent/kademlia/key.h
@@ -20,7 +20,7 @@
#ifndef DHTKEY_H
#define DHTKEY_H
-#include <qcstring.h>
+#include <tqcstring.h>
#include <util/sha1hash.h>
@@ -52,9 +52,9 @@ namespace dht
/**
* Make a key out of a bytearray
* @param ba The QByteArray
*/
- Key(const QByteArray & ba);
+ Key(const TQByteArray & ba);
/**
* Make a key out of a 20 byte array.
@@ -52,9 +52,9 @@ namespace dht
/**
* Make a key out of a bytearray
- * @param ba The QByteArray
+ * @param ba The TQByteArray
*/